#
# spec file for package act
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021 Orville Q. Song <orville@anislet.dev>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         nketos
%global repo            act
%global provider_prefix %{provider}.%{provider_tld}/%{project}
%global import_path     %{provider_prefix}/%{repo}
Name:           act
Version:        0.2.68
Release:        1.2
Summary:        Run your GitHub Actions locally
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/nektos/act
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.gz
BuildRequires:  golang-packaging
BuildRequires:  golang(API) >= 1.16
Requires:       docker
%{go_nostrip}
%{go_provides}

%description
act helps you run your Github Actions locally.

%prep
%setup -q
%setup -q -a1 %{SOURCE1}
sed -i 's_var version = \"v0.2.27-dev\"_var version = "%{version}"_g' main.go

%build
%{goprep} .
mkdir -p vendor/%{provider_prefix}
ln -s . vendor/%{import_path}
%{gobuild} -ldflags "-s -w -X main.Version=v%{version}" .

%install
%{goinstall}

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}

%changelog
* Tue Oct 15 2024 kskarthik@disroot.org
- Update to version 0.2.68:
  * chore: bump VERSION to 0.2.68
  * build(deps): bump github.com/rhysd/actionlint from 1.7.1 to 1.7.3 (#2477)
  * build(deps): bump github.com/creack/pty from 1.1.21 to 1.1.23 (#2468)
  * run_context: add GITHUB_RUN_ATTEMPT (#2458)
  * Fix install sh usage (#2454)
  * bug/issue #2448 - manage special bash options when no shell is defined (#2449)
  * feat: generate a manual page automatically with cobra/doc (#2352)
  * chore: bump VERSION to 0.2.67
  * fix: schema validation for job if functions (#2446)
  * build(deps): bump golang.org/x/term from 0.23.0 to 0.24.0 (#2442)
  * fix: artifact v4 upload above 8MB (#2402)
  * chore: bump VERSION to 0.2.66
  * build(deps): bump golang.org/x/term from 0.22.0 to 0.23.0 (#2421)
  * build(deps): bump megalinter/megalinter from 7.13.0 to 8.0.0 (#2436)
  * build(deps): bump dario.cat/mergo from 1.0.0 to 1.0.1 (#2430)
  * fix GOOS parsing to match expected GHA RUNNER_OS values (#2422)
  * feat: Validate GitHub Actions schema (#2416)
  * chore: bump VERSION to 0.2.65
  * remove double negation in --help (#2405)
  * Bump mergo to v1.0.0 with new module URL (#2403)
  * build(deps): bump github.com/timshannon/bolthold to v0.0.0-20240314194003-30aac6950928 (#2248)
  * Fix #2363. Add /pre- and /post-entrypoint handling (#2394)
  * build(deps): bump golang.org/x/term from 0.21.0 to 0.22.0 (#2387)
  * build(deps): bump github.com/adrg/xdg from 0.4.0 to 0.5.0 (#2398)
  * fix: docker stub and add a test for this (#2355)
  * fix: changed location of actrc in info message (#2373)
  * fix: make node tool non volatile (#2372)
  * fix: add missing service container health check (#2354)
  * build(deps): bump megalinter/megalinter from 7.11.1 to 7.13.0 (#2389)
* Tue Jul  2 2024 kskarthik@disroot.org
- Update to version 0.2.64:
  * chore: bump VERSION to 0.2.64
  * build(deps): bump github.com/spf13/cobra from 1.8.0 to 1.8.1 (#2366)
  * build(deps): bump google.golang.org/protobuf from 1.34.1 to 1.34.2 (#2365)
  * build(deps): bump golang.org/x/term from 0.20.0 to 0.21.0 (#2360)
  * build(deps): bump github.com/docker/cli (#2358)
  * fix: skip service container for empty image (#2281)
  * fix: composite action input pollution (#2348)
  * fix: update reusable workflow input handling (#2349)
  * Add riscv64 binary release (#2350)
  * build(deps): bump github.com/rhysd/actionlint from 1.7.0 to 1.7.1 (#2346)
* Sun Jun  2 2024 kskarthik@disroot.org
- Update to version 0.2.63:
  * chore: bump VERSION to 0.2.63
  * Meta-copy-symlinks-new-actions-cache (#2337)
  * build(deps): bump google.golang.org/protobuf from 1.33.0 to 1.34.1 (#2340)
  * build(deps): bump github.com/golang-jwt/jwt/v5 from 5.2.0 to 5.2.1 (#2341)
  * Actions Artifacts v4 backend (#2224)
  * build(deps): bump github.com/docker/docker (#2333)
  * build(deps): bump github.com/docker/cli (#2332)
  * Add documentation for `dryrun` parameter (#2311)
  * Fix for issue 2232: Many lines of "Could not find any stages to run" on run (#2272)
  * build(deps): bump github.com/docker/cli (#2325)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.27 to 1.7.0 (#2326)
  * build(deps): bump go.etcd.io/bbolt from 1.3.9 to 1.3.10 (#2327)
  * build(deps): bump github.com/docker/docker (#2324)
  * build(deps): bump golangci/golangci-lint-action from 5.3.0 to 6.0.1 (#2323)
  * build(deps): bump golangci/golangci-lint-action from 5.0.0 to 5.3.0 (#2319)
  * build(deps): bump github.com/docker/cli (#2318)
  * build(deps): bump golang.org/x/term from 0.19.0 to 0.20.0 (#2316)
  * build(deps): bump github.com/docker/docker (#2317)
* Thu May  9 2024 kskarthik@disroot.org
- Update to version 0.2.62:
  * chore: bump VERSION to 0.2.62
  * build(deps): bump megalinter/megalinter from 7.10.0 to 7.11.1 (#2309)
  * build(deps): bump golangci/golangci-lint-action from 4.0.0 to 5.0.0 (#2310)
  * build(deps): bump github.com/docker/cli (#2307)
  * build(deps): bump github.com/docker/docker (#2306)
  * build(deps): bump github.com/moby/buildkit from 0.13.1 to 0.13.2 (#2308)
  * build(deps): bump github.com/docker/cli (#2302)
  * Add codespell support (config, workflow to detect/not fix) and make it fix few typos (#2296)
  * build(deps): bump github.com/docker/docker (#2299)
  * build(deps): bump github.com/docker/docker (#2295)
  * build(deps): bump megalinter/megalinter from 7.9.0 to 7.10.0 (#2294)
  * build(deps): bump megalinter/megalinter from 7.8.0 to 7.9.0 (#2216)
  * build(deps): bump golangci/golangci-lint-action from 3.7.0 to 4.0.0 (#2215)
  * build(deps): bump golang.org/x/term from 0.18.0 to 0.19.0 (#2278)
  * build(deps): bump github.com/docker/cli (#2291)
  * Update action.yml (#2293)
  * build(deps): bump github.com/moby/buildkit from 0.12.5 to 0.13.1 (#2253)
  * Bump docker to v26 (#2289)
  * fix: skipped jobs have no result (#2276)
  * fix: favor command-line over files (#2274)
  * chore: fix some comments (#2279)
  * build(deps): bump actions/cache from 3 to 4 (#2163)
  * Remove local action cache if remote has changed (#2284)
  * chore: fix codecov (#2288)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.11.0 to 5.12.0 (#2269)
  * chore: bump VERSION to 0.2.61
  * fix: cache adjust restore order of exact key matches (#2267)
  * Trivial: reduce log spam. (#2256)
  * chore: remove repetitive words (#2259)
  * Support overwriting caches (#2265)
  * test: use ping to improve network test (#2266)
  * build(deps): bump github.com/docker/docker (#2252)
  * build(deps): bump golang.org/x/term from 0.17.0 to 0.18.0 (#2244)
  * fix: rootless permission bits (new actions cache) (#2242)
  * fix function name in comment (#2240)
  * fix: docker buildx cache restore not working (#2236)
  * build(deps): bump github.com/stretchr/testify from 1.8.4 to 1.9.0 (#2235)
* Sat Mar  2 2024 ila.embsys@gmail.com
- Update to version 0.2.60:
  * chore: bump VERSION to 0.2.60
  * build(deps): bump go.etcd.io/bbolt from 1.3.8 to 1.3.9 (#2229)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.26 to 1.6.27 (#2228)
  * fix: logo and demo asset urls (#2226)
  * feat: Test writing remote Actions locally (#2155)
  * build(deps): bump github.com/opencontainers/image-spec (#2223)
  * refactor: simpilfy go-git cache (#2208)
  * feat: offline mode for new action cache (#2173)
  * build(deps): bump github.com/opencontainers/image-spec (#2214)
  * build(deps): bump golang.org/x/term from 0.16.0 to 0.17.0 (#2213)
  * fix: Rootless error concerning `/var/run/docker.sock` (#2181)
  * Shrink Readme (#2198)
  * chore: bump VERSION to 0.2.59
  * feat: correctly use the xdg library, which has the side effect to fix the config survey (#2195)
  * chore: bump VERSION to 0.2.58
  * build(deps): bump github.com/opencontainers/runc from 1.1.7 to 1.1.12 (#2187)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.12.5 (#2188)
  * build(deps): bump github.com/containerd/containerd from 1.6.19 to 1.6.26 (#2189)
  * build(deps): bump github.com/opencontainers/image-spec (#2167)
  * build(deps): bump github.com/moby/buildkit from 0.12.4 to 0.12.5 (#2186)
  * fix: use correct path to toolcache (#1494)
  * refactor: filecollector into new package (#2174)
  * build(deps): bump codecov/codecov-action from 3.1.4 to 3.1.5 (#2175)
  * fix: improve warning about remote not found (#2169)
  * fix: improve new-action-cache fetch failure error (#2172)
  * fix: subpath actions via new artifact cache (#2170)
  * fix: improve action not found error (#2171)
  * refactor(cmd/root): simplify `parseEnvs` (#2162)
  * Add containerd's normalized architectures to archMapper (#2168)
  * build(deps): bump megalinter/megalinter from 7.7.0 to 7.8.0 (#2164)
  * fix: write default config in XDG config dir to avoid cluttering the HOME directory by default (#2140)
  * WorkflowDispatchConfig supports multiple yaml node kinds (#2123)
  * fix: match cache `restore-keys` in creation reverse order (#2153)
  * build(deps): bump actions/upload-artifact from 3 to 4 (#2133)
  * feat: support offline mode (#2128)
  * feat: cli option to enable the new action cache (#1954)
  * ci: automatic merge PRs created by a maintainer and approved by 1 other maintainer (#2156)
  * Add support for NetBSD (#2023)
  * build(deps): bump github.com/cloudflare/circl from 1.3.3 to 1.3.7 (#2149)
  * build(deps): bump golang.org/x/term from 0.15.0 to 0.16.0 (#2148)
  * chore: bump VERSION to 0.2.57
  * build(deps): bump golang.org/x/crypto from 0.16.0 to 0.17.0 (#2134)
  * build(deps): bump github.com/containerd/containerd from 1.7.2 to 1.7.11 (#2136)
  * chore: bump VERSION to 0.2.56
  * build(deps): bump actions/stale from 8 to 9 (#2120)
  * feat: support config env expansion (#2063)
  * build(deps): bump actions/checkout from 3 to 4 (#1998)
  * build(deps): bump github.com/creack/pty from 1.1.20 to 1.1.21 (#2099)
  * Fix noisy `runs-on` error logging (#2102)
  * fix: IsHost is defined as false on windows (#2093)
  * build(deps): bump actions/setup-go from 4 to 5 (#2118)
  * build(deps): bump megalinter/megalinter from 7.6.0 to 7.7.0 (#2119)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.10.1 to 5.11.0 (#2117)
  * build(deps): bump golang.org/x/term from 0.14.0 to 0.15.0 (#2112)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.10.0 to 5.10.1 (#2114)
  * build(deps): bump github.com/moby/buildkit from 0.12.3 to 0.12.4 (#2113)
  * chore: bump VERSION to 0.2.55
  * build(deps): bump megalinter/megalinter from 7.5.0 to 7.6.0 (#2098)
  * build(deps): bump actions/github-script from 6 to 7 (#2097)
  * chore: bump VERSION to 0.2.54
  * build(deps): bump golang.org/x/term from 0.13.0 to 0.14.0 (#2091)
  * Evaluate if condition when calling a reusable workflow (#2087)
  * feat: support runs-on labels and group (#2062)
  * Evaluate all service values (#2054)
  * fix: (#2075)
  * Don't set GITHUB_TOKEN (#2089)
  * Support array expressions in runs-on (#2088)
  * Use unique name for reusable workflow (#2015)
  * build(deps): bump github.com/spf13/cobra from 1.7.0 to 1.8.0 (#2079)
  * fix: panic (#2071)
  * chore: bump VERSION to 0.2.53
  * build(deps): bump github.com/docker/docker (#2067)
  * build(deps): bump github.com/creack/pty from 1.1.18 to 1.1.20 (#2068)
  * build(deps): bump megalinter/megalinter from 7.4.0 to 7.5.0 (#2070)
  * build(deps): bump go.etcd.io/bbolt from 1.3.7 to 1.3.8 (#2065)
  * build(deps): bump github.com/docker/cli (#2069)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.9.0 to 5.10.0 (#2066)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.19 to 0.0.20 (#2059)
  * build(deps): bump github.com/moby/buildkit from 0.12.2 to 0.12.3 (#2060)
  * Add support for service containers (#1949)
  * Fix float formatting (#2018)
  * build(deps): bump golang.org/x/net from 0.15.0 to 0.17.0 (#2045)
  * build(deps): bump github.com/docker/distribution (#2037)
  * build(deps): bump golang.org/x/term from 0.12.0 to 0.13.0 (#2036)
  * fix action_ref (composite action) (#2020)
  * fix: use actions/runner hashfiles in container (#1940)
  * Fix image survey for large images (#2022)
  * [ Variables ] - Add missing documentation for repository variables (#2032)
  * chore: bump VERSION to 0.2.52
  * build(deps): bump github.com/rhysd/actionlint from 1.6.25 to 1.6.26 (#2026)
  * build(deps): bump megalinter/megalinter from 7.3.0 to 7.4.0 (#2025)
  * chore: bump VERSION to 0.2.51
  * build(deps): bump github.com/go-git/go-git/v5 from 5.8.1 to 5.9.0 (#2011)
  * build(deps): bump github.com/opencontainers/image-spec (#2010)
  * build(deps): bump gotest.tools/v3 from 3.5.0 to 3.5.1 (#2009)
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.4.1 to 5.5.0 (#2012)
  * build(deps): bump docker/setup-qemu-action from 2 to 3 (#2007)
  * build(deps): bump goreleaser/goreleaser-action from 4 to 5 (#2008)
  * feat: support node20 runtime (#1988)
  * feat: support interpolation in `<job>.container.options` (#1958)
  * build(deps): bump github.com/docker/docker (#2000)
  * build(deps): bump github.com/docker/cli (#1999)
  * build(deps): bump golang.org/x/term from 0.11.0 to 0.12.0 (#1992)
  * chore: bump VERSION to 0.2.50
  * build(deps): bump github.com/moby/buildkit from 0.12.1 to 0.12.2 (#1986)
  * build(deps): bump github.com/moby/patternmatcher from 0.5.0 to 0.6.0 (#1985)
  * fix: fail if no stages were found (#1970)
  * build(deps): bump golangci/golangci-lint-action from 3.6.0 to 3.7.0 (#1978)
  * Mention act user guide in act (#1973)
  * build(deps): bump megalinter/megalinter from 7.2.1 to 7.3.0 (#1965)
  * ci: change winget job runner to `ubuntu-latest` (#1959)
  * change podman socket path (#1961)
  * Fix "Unknown server OS" for Docker container `--device` option (#1957)
  * refactor: remove unnecessary nil check in RunContext (#1955)
  * feat: Add new Action Cache (#1913)
  * feat: cmd support for windows (#1941)
  * feat: Add CopyTarStream to Container Interface (#1912)
  * refactor: docker build BuildContext field (#1914)
  * Shorten or/and in expressions (#1939)
  * prefer pwsh on windows if found (#1942)
  * build(deps): bump megalinter/megalinter from 7.1.0 to 7.2.1 (#1931)
  * build(deps): bump golang.org/x/term from 0.10.0 to 0.11.0 (#1948)
  * build(deps): bump github.com/moby/buildkit from 0.12.0 to 0.12.1 (#1947)
  * chore: bump VERSION to 0.2.49
  * build(deps): bump github.com/go-git/go-git/v5 from 5.8.0 to 5.8.1 (#1934)
  * build(deps): bump github.com/docker/cli (#1932)
  * build(deps): bump github.com/docker/docker (#1933)
  * build(deps): bump github.com/go-git/go-git/v5 from 5.7.0 to 5.8.0 (#1925)
  * local runner doc (#1911)
  * Add new CLI flag to log just the job id and not the entire job name (#1920)
  * build(deps): bump github.com/moby/buildkit from 0.11.6 to 0.12.0 (#1917)
  * build(deps): bump golang.org/x/term from 0.9.0 to 0.10.0 (#1906)
  * Bump dockercli (#1905)
  * throw when invalid `uses` key is provided (#1804)
  * fix: handle zero size (#1888)
  * chore: upgrade golangci-lint and address findings (#1904)
  * build(deps): bump golangci/golangci-lint-action from 3.5.0 to 3.6.0 (#1868)
  * build(deps): bump gotest.tools/v3 from 3.4.0 to 3.5.0 (#1892)
  * Normalize path outputs emitted by the artifact server download endpoint (#1898)
  * chore: bump VERSION to 0.2.48
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1884)
  * build(deps): bump github.com/opencontainers/image-spec (#1893)
  * Remove `archives.replacements` in `goreleaser.yaml` (#1895)
  * refactor: open boltdb only while using it (#1879)
  * chore: bump VERSION to 0.2.47
  * Allow inputs for workflow_calls (#1845)
  * build(deps): bump github.com/opencontainers/image-spec (#1883)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1882)
  * build(deps): bump github.com/opencontainers/image-spec (#1881)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1880)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.24 to 1.6.25 (#1870)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.6 to 2.3.7 (#1872)
  * build(deps): bump golang.org/x/term from 0.8.0 to 0.9.0 (#1869)
  * build(deps): bump github.com/opencontainers/image-spec (#1871)
  * Allow to override location of action cache dir (#1863)
  * Drop disappeared `wei/curl@v1` (#1864)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1858)
  * build(deps): bump megalinter/megalinter from 7.0.4 to 7.1.0 (#1857)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.18 to 0.0.19 (#1859)
  * fix: spelling mistake in readme (#1854)
  * feature: Add support for github action variables (#1833)
  * Fix bug in processing jobs on platforms without Docker (#1834)
  * build(deps): bump github.com/stretchr/testify from 1.8.2 to 1.8.4 (#1842)
  * build(deps): bump megalinter/megalinter from 7.0.2 to 7.0.4 (#1838)
  * build(deps): bump github.com/docker/cli (#1843)
  * build(deps): bump github.com/imdario/mergo from 0.3.15 to 0.3.16 (#1840)
  * build(deps): bump github.com/sirupsen/logrus from 1.9.2 to 1.9.3 (#1841)
  * build(deps): bump golangci/golangci-lint-action from 3.4.0 to 3.5.0 (#1839)
  * chore: bump VERSION to 0.2.46
  * build(deps): bump github.com/opencontainers/image-spec (#1829)
  * build(deps): bump github.com/docker/cli (#1816)
  * add instruction for using `gh auth token` (#1831)
  * build(deps): bump github.com/go-git/go-git/v5 (#1830)
  * build(deps): bump megalinter/megalinter from 6.22.2 to 7.0.2 (#1827)
  * fix: Update ARCH environment variable used in runners/actions (#1818)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1817)
  * build(deps): bump github.com/sirupsen/logrus from 1.9.0 to 1.9.2 (#1814)
  * build(deps): bump codecov/codecov-action from 3.1.3 to 3.1.4 (#1813)
  * build(deps): bump github.com/opencontainers/image-spec (#1807)
  * build(deps): bump github.com/docker/docker (#1806)
  * build(deps): bump github.com/docker/cli (#1805)
  * build(deps): bump github.com/docker/distribution (#1801)
  * build(deps): bump github.com/cloudflare/circl from 1.1.0 to 1.3.3 (#1800)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1791)
  * Replace backslash in GetActPath() for Windows (#1777)
  * feat: implement steps.timeout-minutes (#1776)
  * fix: don't allow `-self-hosted` mode as container image (#1783)
  * Refactor evaluate yaml node do not alter nested nodes (#1761)
  * fix: fallback to unauthenticated pull (#1774)
  * fix: remove hardcoded reference to github.com when using reusable remote workflows and remote actions (#1784)
  * build(deps): bump github.com/docker/cli (#1780)
  * build(deps): bump github.com/opencontainers/image-spec (#1781)
  * build(deps): bump github.com/docker/docker (#1779)
* Wed May 10 2023 sebix@sebix.at
- Update to version 0.2.45:
  * chore: bump VERSION to 0.2.45
  * Support cache (#1770)
  * chore: run act from cli on linux (#1758)
  * Revert breaking docker socket changes (#1763)
  * avoid using log.Fatal (#1759)
  * build(deps): bump github.com/moby/buildkit from 0.11.5 to 0.11.6 (#1755)
  * build(deps): bump github.com/docker/docker (#1754)
  * build(deps): bump github.com/docker/cli (#1753)
  * build(deps): bump codecov/codecov-action from 3.1.2 to 3.1.3 (#1752)
  * ci: deduplicate running workflows (#1751)
  * fix: try finding a socket, otherwise fail, respect user choice (#1745)
  * Improve watchAndRun (#1743)
  * Remove the comment-out code. (#1691)
  * typo: fix expression of warning message on macOS (#1693)
  * fix: environment handling windows (host mode) (#1732)
  * fix: ensure networkmode "host" unless explicitly specified (#1739)
  * Avoid using `log.Fatal` in `pkg/*` (#1705)
  * feat: support yaml env/secrets/inputs file (#1733)
  * build(deps): bump codecov/codecov-action from 3.1.1 to 3.1.2 (#1735)
  * fix: ghc assignment typo (#1729)
  * fix: reusable workflow panic (#1728)
  * fix: add `server_url` attribute to github context (#1727)
  * build(deps): update go-git to ce62f3e9ff86270538a514a68d3bd5563a733e3b (#1725)
  * build(deps): bump github.com/docker/docker (#1719)
  * build(deps): bump github.com/spf13/cobra from 1.6.1 to 1.7.0 (#1724)
  * build(deps): bump github.com/docker/cli (#1722)
  * build(deps): bump megalinter/megalinter from 6.22.1 to 6.22.2 (#1720)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.23 to 1.6.24 (#1721)
  * build(deps): bump golang.org/x/term from 0.6.0 to 0.7.0 (#1723)
  * build(deps): bump github.com/docker/cli (#1712)
  * build(deps): bump github.com/docker/docker (#1711)
  * build(deps): bump megalinter/megalinter from 6.21.0 to 6.22.1 (#1710)
  * chore: bump VERSION to 0.2.44
  * build(deps): bump github.com/opencontainers/runc from 1.1.3 to 1.1.5 (#1708)
  * feat: improve GetOutboundIP (#1707)
  * fix: use os.UserHomeDir (#1706)
  * Make sure working directory is respected when configured from matrix (#1686)
  * build(deps): bump github.com/moby/buildkit from 0.11.4 to 0.11.5 (#1703)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.17 to 0.0.18 (#1702)
  * build(deps): bump github.com/imdario/mergo from 0.3.14 to 0.3.15 (#1701)
  * build(deps): bump actions/stale from 7 to 8 (#1700)
  * build(deps): bump megalinter/megalinter from 6.20.1 to 6.21.0 (#1699)
  * full path required for extension install (#1670)
  * build(deps): bump actions/setup-go from 3 to 4 (#1689)
  * build(deps): bump github.com/imdario/mergo from 0.3.13 to 0.3.14 (#1688)
  * build(deps): bump github.com/stretchr/testify from 1.8.1 to 1.8.2 (#1650)
  * build(deps): bump megalinter/megalinter from 6.20.0 to 6.20.1 (#1679)
  * build(deps): bump fregante/setup-git-user from 1 to 2 (#1664)
  * Add example command for collecting artifacts (#1671)
  * feat: specify matrix on command line (#1675)
  * Support for docker steps in host environment (#1674)
  * fix: correct ref and ref_name (#1672)
  * fix: return err in walk (#1667)
  * test: Enshure ForcePull config doesn't break docker actions (1661)
  * fix: crash if the id tool fails to run in the container (1660)
  * build(deps): bump github.com/moby/buildkit from 0.11.3 to 0.11.4 (#1669)
  * build(deps): bump megalinter/megalinter from 6.19.0 to 6.20.0 (#1665)
  * build(deps): bump golang.org/x/term from 0.5.0 to 0.6.0 (#1666)
  * Improve XDG Spec supporting (#1656)
  * fix: safe file name (#1651)
  * fix: compare properties of Invalid types (#1645)
  * chore: bump VERSION to 0.2.43
  * fix: github.job property is empty, GITHUB_JOB should be job id (#1646)
  * build(deps): bump github.com/opencontainers/image-spec (#1649)
  * fix: update output handling for reusable workflows (#1521)
  * fix: crash malformed composite action (#1616)
  * docs: remove help section (#1648)
  * feat: workflowpattern package (#1618)
  * build(deps): bump github.com/containerd/containerd from 1.6.16 to 1.6.18 (#1637)
  * fix: add GITHUB_STEP_SUMMARY (#1607)
  * build(deps): bump golang.org/x/net from 0.4.0 to 0.7.0 (#1636)
  * build(deps): bump github.com/moby/buildkit from 0.11.2 to 0.11.3 (#1635)
  * fix: tolerate workflow that needs a missing job (#1595) (#1619)
  * chore: Remove obsolete Container.UpdateFromPath (#1631)
  * chore: use new style octal (#1630)
  * fix: don't override env (#1629)
  * ci: add Winget Releaser workflow (#1623)
  * build(deps): bump github.com/opencontainers/selinux (#1625)
  * build(deps): bump github.com/docker/docker (#1624)
  * build(deps): bump github.com/docker/cli (#1626)
  * chore: add Winget installation instructions (#1622)
  * Pass dockerfile to build executor (#1606)
  * build(deps): bump github.com/docker/cli from 23.0.0-rc.1+incompatible to 23.0.0+incompatible (#1611)
  * build(deps): bump github.com/docker/docker (#1613)
  * build(deps): bump megalinter/megalinter from 6.18.0 to 6.19.0 (#1610)
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.4.0 to 5.4.1 (#1612)
  * build(deps): bump github.com/joho/godotenv from 1.4.0 to 1.5.1 (#1614)
  * refactor: GITHUB_ENV command / remove env.PATH (#1503)
  * Update max container name length (#1597)
  * feat: allow overriding of `GITHUB_` env variables (#1582)
  * Docker build fixes (#1596)
  * fix: Apply forcePull only for prebuild docker actions (#1599)
  * chore: bump VERSION to 0.2.42
  * feat: cache notices to reduce frequency of upgrade notifications (#1592)
  * chore: fix release script to trigger gh-act
  * chore: bump VERSION to 0.2.41
  * build(deps): bump github.com/moby/buildkit from 0.11.1 to 0.11.2 (#1589)
  * build(deps): bump golangci/golangci-lint-action from 3.3.1 to 3.4.0 (#1590)
  * cI: make stalebot less annoying (#1587)
  * test: Do not leak step env in composite (#1585)
  * feat: step summary of test results (#1580)
  * build(deps): bump github.com/moby/buildkit from 0.11.0 to 0.11.1 (#1576)
  * build(deps): bump golang.org/x/term from 0.3.0 to 0.4.0 (#1577)
  * build(deps): bump github.com/docker/docker (#1573)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.22 to 1.6.23 (#1574)
  * build(deps): bump actions/github-script from 5 to 6 (#1572)
  * chore: update docs for installing act as GH CLI extension
  * feat: release extension
  * feat: release extension
  * feat: release extension
  * refactor: pull and rebuild docker by default (#1569)
  * feat: add remote reusable workflows (#1525)
  * Fixed auto-generated platform configuration with Micro size image (#1566)
  * Feature/allow worktrees (#1530)
  * chore: bump VERSION to 0.2.40
  * fix: update artifact server to address GHSL-2023-004 (#1565)
  * chore: bump VERSION to 0.2.39
  * chore: fix promote script
  * chore: bump version
  * chore: makefile update
  * chore: bump version
  * build(deps): bump github.com/moby/buildkit from 0.10.6 to 0.11.0 (#1563)
  * chore: push new version
  * Readme: Fix shell installation (#1547)
  * fix: allow override of artifact server bind address (#1560)
  * feat: add check for newer versions (#1562)
  * Input (#1524)
  * refactor: remove docker image list reference filter (#1501)
  * fix: add-matcher fails github workflow (#1532)
  * feat: add support for building docker actions with private registries (#1557)
  * build(deps): bump github.com/containerd/containerd from 1.6.6 to 1.6.12 (#1554)
  * feat: Allow building without docker support (#1507)
  * fix: extra path lost in composite actions (#1531)
  * test: make sure workflow_call is not a github event calling our workflow (#1520)
  * fix: preserve job result state in case of failure (#1519)
  * build(deps): bump megalinter/megalinter from 6.17.0 to 6.18.0 (#1550)
  * build(deps): bump megalinter/megalinter from 6.16.0 to 6.17.0 (#1540)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.16 to 0.0.17 (#1539)
  * build(deps): bump github.com/go-git/go-billy/v5 from 5.3.1 to 5.4.0 (#1541)
  * build(deps): bump megalinter/megalinter from 6.15.0 to 6.16.0 (#1534)
  * build(deps): bump actions/stale from 6 to 7 (#1535)
  * revert: deprecation of containerArchitecture (#1514)
  * build(deps): bump goreleaser/goreleaser-action from 3 to 4 (#1515)
  * build(deps): bump github.com/docker/cli (#1516)
  * build(deps): bump github.com/docker/docker (#1517)
  * fix: align runner.os / runner.arch to known values (#1510)
  * feat: Support "result" on "needs" context. (#1497)
  * fix: tail (not absolute) as entrypoint of job container (#1506)
  * refactor: fix savestate in pre steps (#1466)
  * feat: allow to spawn and run a local reusable workflow (#1423)
  * refactor: fix add-path / GITHUB_PATH commands (#1472)
  * feat: JobLoggerFactory (#1496)
  * fix: handle env-vars case sensitive (#1493)
  * fix: step env is unavailable in with property expr (#1458)
  * refactor: share UpdateFromEnv logic (#1457)
  * feat: `--container-options` (#1462)
  * refactor: move autoremove into the jobexecutor (#1463)
  * docs: clarifying skipping steps / jobs (#1480)
  * Pass `LANG=C.UTF-8` to environment (#1476)
  * build(deps): bump megalinter/megalinter from 6.14.0 to 6.15.0 (#1475)
  * act -j -W example (#1471)
  * Fix shellcommand error on sh shell (#1464)
  * fix typo (#1456)
  * build(deps): bump github.com/creack/pty from 1.1.17 to 1.1.18 (#1447)
  * fix: handle subdirectors and exclusions (#1012) (#1446)
  * Remove dead code (#1425)
  * feat: interpolate the step names (#1422)
  * feat: GITHUB_STATE and GITHUB_OUTPUT file commands (#1391)
  * feat: Host environment (#1293)
  * build(deps): bump github.com/moby/buildkit from 0.10.5 to 0.10.6 (#1437)
  * fix: keep path to event json file in composite actions (#1428)
  * build(deps): bump golangci/golangci-lint-action from 3.3.0 to 3.3.1 (#1436)
  * fix: nil pointer access ( workflow_dispatch )
  * Update number of approvers required from 3 to 2
  * build(deps): bump megalinter/megalinter from 6.13.0 to 6.14.0 (#1426)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.21 to 1.6.22 (#1427)
  * feat: parse types of reusable workflows (#1414)
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#1420)
  * build(deps): bump github.com/docker/docker (#1418)
  * build(deps): bump github.com/docker/cli (#1419)
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#1404)
  * refactor: move from io/ioutil to io and os packages (#1417)
  * Add user level Docker socket to common paths (#1416)
  * build(deps): bump megalinter/megalinter from 6.12.0 to 6.13.0 (#1407)
  * build(deps): bump golangci/golangci-lint-action from 3.2.0 to 3.3.0 (#1408)
  * build(deps): bump github.com/docker/docker (#1403)
  * build(deps): bump github.com/docker/cli (#1405)
  * build(deps): bump github.com/moby/buildkit from 0.10.4 to 0.10.5 (#1406)
  * Fixes #1387 (#1388)
  * build(deps): bump megalinter/megalinter from 6.11.1 to 6.12.0 (#1395)
  * build(deps): bump github.com/docker/cli (#1393)
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#1394)
  * build(deps): bump github.com/docker/docker (#1392)
  * Mapping `workflow_dispatch` inputs into the Expression `inputs` context (#1363)
  * fix: ci is failing since 2022-10-17 (#1397)
  * test: add test for networking setup in act (#1375)
  * fix: re-evaluate env for remote composite actions (#1385)
  * build(deps): bump megalinter/megalinter from 6.11.0 to 6.11.1 (#1381)
  * build(deps): bump gotest.tools/v3 from 3.0.3 to 3.4.0 (#1379)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.20 to 1.6.21 (#1380)
  * build(deps): bump github.com/imdario/mergo from 0.3.12 to 0.3.13 (#1378)
  * fix: interpolate action input defaults (#1376)
  * fix: support docker create arguments from container.options (#1022) (#1351)
  * Fix composite input handling (#1345)
  * fix: handle go closure iteration (#1374)
  * build(deps): bump megalinter/megalinter from 5 to 6.11.0 (#1370)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.19 to 1.6.20 (#1371)
  * build(deps): bump github.com/opencontainers/selinux (#1372)
  * fix: show workflow info even if on.push is not defined (#1329) (#1335)
  * fix: restore the job logger setup after job cancelation (#1365)
  * feat: pass current matrix information to job logger (#1364)
  * fix: align github.ref to GitHub Action (#1362)
  * fix: crash on invalid docker credentials (#1348)
  * fix: missing defaults in nodejs pre (#1349)
  * build(deps): bump codecov/codecov-action from 3.1.0 to 3.1.1 (#1359)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.18 to 1.6.19 (#1360)
  * build(deps): bump actions/stale from 5 to 6 (#1357)
  * Arch best practice is to not run partial upgrades (#1355)
  * Improve hint for inserting secrets securely (#1354)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.17 to 1.6.18 (#1352)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.5 to 2.3.6 (#1341)
  * build(deps): bump github.com/docker/cli (#1340)
  * build(deps): bump github.com/docker/docker (#1339)
  * fix: support expression for step's continue-on-error field (#900) (#1331)
  * fix: show workflow name when get error on yml parsing (#1133) (#1328)
  * help output: use consistent terminology between `-j` & `-l` (#1326)
  * support runner.arch (#1290)
  * build(deps): bump github.com/moby/buildkit from 0.10.3 to 0.10.4 (#1322)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.16 to 1.6.17 (#1321)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to 0.0.16 (#1312)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.15 to 1.6.16 (#1311)
  * build(deps): bump github.com/go-ini/ini from 1.66.6 to 1.67.0 (#1305)
  * refactor: ignore already closed error (#1285)
  * fix: CI is unstable due to new linting rules (#1292)
* Wed Jan 11 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.34
- Spec file:
  Fix bsc#1207021 to report the correct version when calling "act --version"
  Wrong version is fixed with sed in act-0.2.34/main.go
  Reported upstream as GH://nektos/act#1555
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.34
- Update to version 0.2.34:
  * feat: interpolate the step names (#1422)
  * feat: GITHUB_STATE and GITHUB_OUTPUT file commands (#1391)
  * feat: Host environment (#1293)
  * feat: parse types of reusable workflows (#1414)
  * fix: handle subdirectors and exclusions (#1012) (#1446)
  * fix: keep path to event json file in composite actions (#1428)
  * fix: nil pointer access ( workflow_dispatch )
  * build(deps): bump megalinter/megalinter from 6.14.0 to 6.15.0 (#1475)
  * act -j -W example (#1471)
  * Fix shellcommand error on sh shell (#1464)
  * fix typo (#1456)
  * build(deps): bump github.com/creack/pty from 1.1.17 to 1.1.18 (#1447)
  * Remove dead code (#1425)
  * build(deps): bump github.com/moby/buildkit from 0.10.5 to 0.10.6 (#1437)
  * build(deps): bump golangci/golangci-lint-action from 3.3.0 to 3.3.1 (#1436)
  * Update number of approvers required from 3 to 2
  * build(deps): bump megalinter/megalinter from 6.13.0 to 6.14.0 (#1426)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.21 to 1.6.22 (#1427)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.33
- Update to version 0.2.33:
  * fix: ci is failing since 2022-10-17 (#1397)
  * fix: re-evaluate env for remote composite actions (#1385)
  * fix: interpolate action input defaults (#1376)
  * fix: support docker create arguments from container.options (#1022) (#1351)
  * fix: handle go closure iteration (#1374)
  * build(deps): bump github.com/spf13/cobra from 1.6.0 to 1.6.1 (#1420)
  * build(deps): bump github.com/docker/docker (#1418)
  * build(deps): bump github.com/docker/cli (#1419)
  * build(deps): bump github.com/stretchr/testify from 1.8.0 to 1.8.1 (#1404)
  * refactor: move from io/ioutil to io and os packages (#1417)
  * Add user level Docker socket to common paths (#1416)
  * build(deps): bump megalinter/megalinter from 6.12.0 to 6.13.0 (#1407)
  * build(deps): bump golangci/golangci-lint-action from 3.2.0 to 3.3.0 (#1408)
  * build(deps): bump github.com/docker/docker (#1403)
  * build(deps): bump github.com/docker/cli (#1405)
  * build(deps): bump github.com/moby/buildkit from 0.10.4 to 0.10.5 (#1406)
  * Fixes #1387 (#1388)
  * build(deps): bump megalinter/megalinter from 6.11.1 to 6.12.0 (#1395)
  * build(deps): bump github.com/docker/cli (#1393)
  * build(deps): bump github.com/spf13/cobra from 1.5.0 to 1.6.0 (#1394)
  * build(deps): bump github.com/docker/docker (#1392)
  * Mapping workflow_dispatch inputs into the Expression inputs context (#1363)
  * test: add test for networking setup in act (#1375)
  * build(deps): bump megalinter/megalinter from 6.11.0 to 6.11.1 (#1381)
  * build(deps): bump gotest.tools/v3 from 3.0.3 to 3.4.0 (#1379)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.20 to 1.6.21 (#1380)
  * build(deps): bump github.com/imdario/mergo from 0.3.12 to 0.3.13 (#1378)
  * Fix composite input handling (#1345)
  * build(deps): bump megalinter/megalinter from 5 to 6.11.0 (#1370)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.19 to 1.6.20 (#1371)
  * build(deps): bump github.com/opencontainers/selinux (#1372)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.32
- Update to version 0.2.32:
  * feat: pass current matrix information to job logger (#1364)
  * fix: show workflow info even if on.push is not defined (#1329) (#1335)
  * fix: restore the job logger setup after job cancelation (#1365)
  * fix: align github.ref to GitHub Action (#1362)
  * fix: crash on invalid docker credentials (#1348)
  * fix: missing defaults in nodejs pre (#1349)
  * fix: support expression for step's continue-on-error field (#900) (#1331)
  * fix: show workflow name when get error on yml parsing (#1133) (#1328)
  * build(deps): bump codecov/codecov-action from 3.1.0 to 3.1.1 (#1359)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.18 to 1.6.19 (#1360)
  * build(deps): bump actions/stale from 5 to 6 (#1357)
  * Arch best practice is to not run partial upgrades (#1355)
  * Improve hint for inserting secrets securely (#1354)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.17 to 1.6.18 (#1352)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.5 to 2.3.6 (#1341)
  * build(deps): bump github.com/docker/cli (#1340)
  * build(deps): bump github.com/docker/docker (#1339)
* Sat Dec 10 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 0.2.31
- Update to version 0.2.31:
  * fix: CI is unstable due to new linting rules (#1292)
  * help output: use consistent terminology between -j & -l (#1326)
  * support runner.arch (#1290)
  * build(deps): bump github.com/moby/buildkit from 0.10.3 to 0.10.4 (#1322)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.16 to 1.6.17 (#1321)
  * build(deps): bump github.com/mattn/go-isatty from 0.0.14 to 0.0.16 (#1312)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.15 to 1.6.16 (#1311)
  * build(deps): bump github.com/go-ini/ini from 1.66.6 to 1.67.0 (#1305)
  * refactor: ignore already closed error (#1285)
* Wed Aug 10 2022 jayvdb@gmail.com
- Update to version 0.2.30:
  * fix: ensure all post steps are executed (#1286)
  * walk submodule path instead of dir name (#1282)
  * fix: add parent step id in composite action step id (#1268)
  * Made env interpolated instead of evaluated. (#1222)
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#1273)
  * Update README.md (#1260)
  * lint: add ReadHeaderTimeout (#1277)
  * fix: the number in the github event is of type number (#1252)
  * only perform chown operation for non root users (#1250)
  * fix: allow TimeoutMinutes to be expression in Jobs (#1247)
  * fix: use docker images from dockerhub (#1249)
  * Improve --eventpath example command (#1243)
  * Improve docs for events inputs (#1238)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.14 to 1.6.15 (#1239)
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0 (#1240)
* Sun Jul  3 2022 elimat@opensuse.org
- Update to version 0.2.29:
  * build(deps): bump github.com/rhysd/actionlint from 1.6.13 to 1.6.14 (#1234)
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#1233)
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.5 (#1232)
  * fix: checkout container path should always use `/` (#1226)
  * feat: add option to bypass GHE for actions checkout (#1162)
  * revert auto changelog generator
  * ignore release-notes.md to avoid dirty check in goreleaser
  * update to use PAT
  * setup git user
  * allow workflow_dispatch on tag-monthly
  * add monthly release
  * auto generate changelog (#1225)
  * update runc and containerd (#1224)
  * feat: non root user container (#1202)
  * fix: processing of strategy.matrix.include (#1200)
  * fix: localcheckout mock (#1198)
  * Added support for chunked uploads. (#1208)
  * fix: keep action inputs (#1215)
  * Improve logging (#1171)
  * fix: allow TimeoutMinutes to be expression (#1217)
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#1213)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.4 to 2.3.5 (#1214)
  * build(deps): bump github.com/docker/cli (#1211)
  * build(deps): bump github.com/docker/docker (#1212)
  * refactor: remove github.com/pkg/errors dependency (#1077)
  * fix: skip local actions pre step in any case (#1204)
  * pkg/runner: add support to replace GitHub's env (#1197)
  * fix: dryrun skip local actions + enable Tests (#1199)
  * fix: Remove volume with same name as the container again (#1203)
  * build(deps): bump github.com/go-ini/ini from 1.66.5 to 1.66.6 (#1201)
  * build(deps): bump github.com/go-ini/ini from 1.66.4 to 1.66.5 (#1189)
  * governance: fix bug report rendering (#1186)
  * update docs (#1180)
  * feat: handle context cancelation during docker exec (#1170)
  * implement pre and post steps (#1089)
  * fix: remove composite restrictions (#1128)
  * governance: new issue templates (#1048)
  * ci(choco): update chocolatey to 1.1.0 (#1164)
  * build(deps): bump goreleaser/goreleaser-action from 2 to 3 (#1179)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.12 to 1.6.13 (#1173)
  * feat: add ubuntu-22.04 (#1150)
  * feat/bug-report-extended (#1163)
  * build(deps): bump golangci/golangci-lint-action from 3.1.0 to 3.2.0 (#1169)
  * build(deps): bump github.com/docker/docker (#1167)
  * build(deps): bump github.com/docker/cli (#1168)
  * fix: panic if a step in a job is nil (#1145)
  * fix: return invalid step type (#1157)
  * Remove the correct Volume (#1148)
  * fix: panic while running DRYRUN with local actions (#1141)
  * refactor: remove composite action runcontext workaround (#1085)
  * build(deps): bump github.com/moby/buildkit from 0.10.2 to 0.10.3 (#1153)
  * build(deps): bump docker/setup-qemu-action from 1 to 2 (#1156)
  * build(deps): bump github.com/docker/docker (#1155)
  * build(deps): bump github.com/docker/cli (#1154)
  * feat: support `GITHUB_REF_NAME` & `GITHUB_REF_TYPE` (#1142)
  * build(deps): bump github.com/moby/buildkit from 0.10.1 to 0.10.2 (#1147)
  * fix: conclusion and outcome are no integers (#1136)
  * fix: do not error that much (#1137)
  * build(deps): bump codecov/codecov-action from 3.0.0 to 3.1.0 (#1139)
  * chore: fold integration test outputs (#1111)
  * Update README.md (#1121)
  * docs(README): remove go install (#1123)
  * ci: always grab latest go version (#1124)
  * tests: remove runTestJobFile (#1127)
  * use new paths from goreleaser (#1135)
  * README: add MacPorts badge (#1129)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.11 to 1.6.12 (#1126)
  * build(deps): bump codecov/codecov-action from 2.1.0 to 3.0.0 (#1118)
  * build(deps): bump github.com/moby/buildkit from 0.10.0 to 0.10.1 (#1116)
  * build(deps): bump actions/upload-artifact from 2 to 3 (#1119)
  * build(deps): bump actions/setup-go from 2 to 3 (#1120)
  * build(deps): bump actions/stale from 4 to 5 (#1117)
  * tests(runner): move arm64 test to own func (#1095)
  * build(deps): bump deps which dependabot doesn't want to (#1107)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.10 to 1.6.11 (#1106)
  * implement volume mount for container job (#1101)
  * feat: add option to specify git remote name (#1104)
  * Allow passed in env vars to supersede ones declared in the workflow (#1100)
  * fix: copy ignored tracked files (#1074)
  * build(deps): bump github.com/opencontainers/selinux (#1102)
  * fix: return error on reusable workflows (#1093)
  * deps: bump go.mod to go1.18 (#1088)
  * fix(editorconfig): correct braces (#1094)
  * ci: bump go to 1.18 (#1087)
  * fix: don't overwrite with empty cmd/entrypoint (#1076)
  * refactor: simplify action function signatures (#1083)
  * deps: remove shlex (#1086)
  * fix: set default version string (#1070)
  * build(deps): bump actions/cache from 2 to 3 (#1082)
  * build(deps): bump github.com/docker/docker (#1080)
  * build(deps): bump github.com/AlecAivazis/survey/v2 from 2.3.2 to 2.3.4 (#1079)
  * build(deps): bump github.com/docker/cli (#1081)
  * automatically merge PRs from dependabot (#1084)
  * deps: bump go-git (#1057)
  * feat: split job steps into its own files/structs (#1004)
  * feat: add bug-report flag (#1056)
  * Fix: panic: reflect: slice index out of range (#1066)
  * Fix: call of reflect.Value.Interface on zero Value (#1067)
  * Fix: tojson(null) == 'null' (#1068)
  * build(deps): bump github.com/docker/docker (#1062)
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1 (#1061)
  * feat: add flag to always run the checkout action (#1049)
  * Revert: Don't stop JobContainer on failure (#1041)
  * fix: remove unused TestContext (#1013)
  * feat: add step name to logger field (#1027)
  * fix: coerce booleans to numbers for comparison in exprparser (#1030)
  * feat: add json logger output (#1026)
  * build(deps): bump golangci/golangci-lint-action from 2 to 3.1.0 (#1019)
  * ci(stalebot): ignore feature requests (#1017)
  * build(deps): bump actions/checkout from 2 to 3 (#1028)
  * build(deps): bump github.com/spf13/cobra from 1.3.0 to 1.4.0 (#1040)
  * build(deps): bump github.com/docker/cli (#1038)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.9 to 1.6.10 (#1039)
  * build(deps): bump github.com/docker/distribution (#1037)
  * build(deps): bump github.com/moby/buildkit from 0.9.3 to 0.10.0 (#1036)
  * fix: trim whitespace from actrc (#1024)
  * fix: hide masked values in log files (#1011)
  * build(deps): bump github.com/spf13/cobra from 1.2.1 to 1.3.0 (#955)
  * Update link to 'filesystems' GitHub docs (#1016)
  * build(deps): bump github.com/rhysd/actionlint from 1.6.8 to 1.6.9 (#1018)
  * feat: run jobs in parallel (#1003)
  * Expression evaluator fixes (#1009)
  * build(deps): bump github.com/go-ini/ini from 1.64.0 to 1.66.4 (#997)
  * fix: print line after password prompt (#1014)
  * refactor: default empty if: statement to if: success() in evaluator & remove `FixIfStatement()` (#990)
  * fix: deep evaluate matrix strategy (#964)
  * build(deps): bump github.com/docker/distribution (#994)
  * Added instructions to install on fedora using copr package (#993)
  * fix: always execute closeContainer() executor (#988)
  * refactor: extract setupAction into ActionReader (#986)
  * refactor: extract RunContext Executor in JobExecutor (#984)
  * docs: Expand the GITHUB_TOKEN section (#968)
  * ci(Mergify): configuration update (#972)
  * fix: docker cp of dangling symlink (#943) (#948)
  * Fix: regression run after failure (#971)
  * ci(Mergify): configuration update (#966)
  * build(deps): bump github.com/moby/buildkit from 0.9.2 to 0.9.3 (#958)
  * build(deps): bump github.com/docker/docker (#957)
  * build(deps): bump github.com/opencontainers/image-spec (#954)
  * build(deps): bump github.com/docker/cli (#956)
  * Test: env.ACT in if condition of the workflow (#965)
  * feat: add skipped status as step result (#950)
  * feat: try to read ref and sha from event payload if available (#889)
  * fix: set composite outputs on failure (#945)
  * Refactor expression evaluator to use parser from actionlint package (#908)
  * fix(goreleaser): add append mode for release notes (#962)
  * feat(goreleaser): format changelog, add prereleases (#942)
  * fix: update install.sh (#937)
  * refactor: export and move shared contexts into pkg/model (#931)
  * feat: add node16 support (#922)
  * Feature: uses in composite (#793)
  * lint(megalinter): disable markdown link check (#938)
  * ci: replace superlinter with megalinter (#923)
  * fix: rework setupShellCommand (#930)
  * fix: clarify --reuse and --rm flags (#929)
  * ci(Mergify): configuration update (#924)
  * fix: ::stop-commands:: should continue to print the lines (#920)
  * fix: continue jobs + steps after failure (#840)
  * Fix and test choco action (#911)
  * Docker auth (#891)
  * container credentials (#868)
  * Add more steps context support (#887)
  * feat: allow existing logger from context (#898)
  * feat: SELinux lables for --bind (#906)
  * ci(choco): fix chocolatey docker build (#903)
- Add go modules (vendor) suport in _service file
- run spec-cleaner
* Sun Dec  5 2021 Orville Q. Song <orville@anislet.dev>
- Update to version 0.2.25:
  * feat: add option for docker image rebuild (#878)
  * Don't interpolate joboutputs, before job is done (#894)
  * Fix regex for GITHUB_ENV parsing (#893)
  * Revert "feat: allow existing logger from context (#859)" (#890)
  * docs: add brew installation from HEAD (#886)
  * build(deps): bump github.com/go-ini/ini from 1.63.2 to 1.64.0 (#882)
  * fix: fromJSON should work with any JSON (#883)
  * fix: correctly unmarshal entrypoint (#876)
  * fix: use docker lib for image ref parsing (#877)
  * Fix github SSH regex for missing .git extension (#871)
* Sat Dec  4 2021 Orville Q. Song <orville@anislet.dev>
- Init act Package.
  Run your GitHub Actions locally. 🚀
  Current Release: v0.2.25
  Commit Hash: 8ad6c07083c7cd7f45ea9e0808e3297bf2370ab5
